OWhile class

Mixed-in types

Constructors

OWhile({required DStatement condition, required DCodeLines<DStatement> lines})

Properties

condition ↔ DStatement
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
lines ↔ DCodeLines<DStatement>
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
to map
inherited
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited