DBool class abstract

Inheritance
Implementers

Constructors

DBool()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapStatementName → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DType
final
value → bool
no setteroverride

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunTip tip) → dynamic
override
toMap() → Map
to map
inherited
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

statementName → String
final

Static Methods

fromMap(FormMapTip f, Map m) → DBool