DConstant class abstract

プログラムに書き込む定数値

Implemented types
Implementers

Constructors

DConstant()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapStatementName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DType?
no setterinherited
value → dynamic
no setter

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunTip tip) → dynamic
inherited
toMap() → Map
to map
override
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited