DExpression class abstract

A DExpression is a can get value object. expression allway return a value.

Inheritance
Implemented types
Implementers

Constructors

DExpression()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DType?
no setter

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunTip tip) → dynamic
inherited
toMap() → Map
to map
inherited
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited