DMap class abstract

Implemented types
Implementers

Constructors

DMap()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyType → DType?
no setter
map → Map<DExpression, DExpression>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DType
no setteroverride
valueType → DType?
no setter

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
override
getKeyType() → DType
getValueType() → DType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunTip tip) → dynamic
override
toMap() → Map
to map
override
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

statementName → String
final