OMap class

Mixed-in types

Constructors

OMap({required Map<DExpression, DExpression> map, DType? keyType, DType? valueType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyType ↔ DType?
getter/setter pairoverride-getter
map ↔ Map<DExpression, DExpression>
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DType
no setterinherited
valueType ↔ DType?
getter/setter pairoverride-getter

Methods

getIterable() → Iterable<StatementInfo>
get iterable to for each statements, each statement will yield itself first
inherited
getKeyType() → DType
inherited
getValueType() → DType
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunTip tip) → dynamic
inherited
toMap() → Map
to map
inherited
toString() → String
A string representation of this object.
inherited
tran(LanguageTip tip) → String
transform to target code, the target information is in the tip
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited