DJava class

Inheritance

Constructors

DJava()

Properties

hashCode → int
The hash code for this object.
no setterinherited
indent ↔ int
今のインデント
getter/setter pairinherited
keywords → Map<String, String>
final
operatorInfoMap ↔ Map<String, OperatorInfo>
getter/setter pair
rule → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → Map<String, bool>
final
typeMap → Map<String, String>
final

Methods

addIndent() → void
inherited
getKeyword(String name) → String
override
getOperatorInfo(String index) → OperatorInfo
override
getRule(String index) → String
転換ルールの指向
override
getSetting(String index) → bool
override
getType(String name) → String?
適合したタイプの指向
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIndent() → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited