LanguageTip class abstract

Implementers

Constructors

LanguageTip()

Properties

hashCode → int
The hash code for this object.
no setterinherited
indent ↔ int
今のインデント
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addIndent() → void
getKeyword(String name) → String
getOperatorInfo(String index) → OperatorInfo
getRule(String index) → String
転換ルールの指向
getSetting(String index) → bool
getType(String name) → String?
適合したタイプの指向
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIndent() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited