OperatorInfo class

Constructors

OperatorInfo({required Fixity fixity, required int preceding, required String sign})

Properties

fixity ↔ Fixity
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
preceding ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sign ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override