FormMapTip class

Constructors

FormMapTip({required DBool boolFunc(bool), required DString stringFunc(String), required DPrint printFunc(DExpression), required DCodeLines<DStatement> codeLinesFunc({required List<DStatement> codeLines})})
const

Properties

boolFunc → DBool Function(bool)
final
codeLinesFunc → DCodeLines<DStatement> Function({required List<DStatement> codeLines})
final
hashCode → int
The hash code for this object.
no setterinherited
printFunc → DPrint Function(DExpression)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringFunc → DString Function(String)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited